@@ -27,7 +27,8 @@ module Control.Monad.RWS.Lazy (
     mapRWS,
     withRWS,
     -- * The RWST monad transformer
-    RWST(..),
+    RWST(RWST),
+    runRWST,
     evalRWST,
     execRWST,
     mapRWST,
@@ -45,7 +46,7 @@ import Control.Monad.RWS.Class
 import Control.Monad.Trans
 import Control.Monad.Trans.RWS.Lazy (
     RWS, rws, runRWS, evalRWS, execRWS, mapRWS, withRWS,
-    RWST(..), evalRWST, execRWST, mapRWST, withRWST)
+    RWST(RWST), runRWST, evalRWST, execRWST, mapRWST, withRWST)
 
 import Control.Monad
 import Control.Monad.Fix
